# Copyright 2017 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import absolute_import

from google.cloud.speech_v1.gapic import speech_client
from google.cloud.speech_v1.gapic import enums

from google.cloud.speech_v1.helpers import SpeechHelpers
from google.cloud.speech_v1 import types


class SpeechClient(SpeechHelpers, speech_client.SpeechClient):
    __doc__ = speech_client.SpeechClient.__doc__
    enums = enums
    types = types


__all__ = ("enums", "SpeechClient", "types")
